rm(list=ls())
library(dplyr)
library(tidyverse)
library(ggpubr)
library(rstatix)
library(readxl)
library(lme4)
contr=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=10000000))
setwd("")

#Study 1. Replication of the study by Brauer et al. (2009).

###Model 1: Combining new and old (from Brauer 2009) data to assess effect of "condition" on bonobos' participation

xdata <- read.table("Radovanovic et al.IA_bonobos_Study1_model1.txt", header=T, sep="\t")

str(xdata)

#Models

full=glmer(cbind(Exchange, No_exchange)~Condition+(1|Partner)+(1|Subject)+(1|dyad), family=binomial, data=xdata, control=contr)
full_study=glmer(cbind(Exchange, No_exchange)~Condition*study+(1|Partner)+(1|Subject)+(1|dyad), family=binomial, data=xdata, control=contr)

brauer=glmer(cbind(Exchange, No_exchange)~Condition+(1|Partner) + (1|Subject)+(1|dyad), family=binomial, data=xdata[xdata$study=="Brauer",], control=contr)
kia=glmer(cbind(Exchange, No_exchange)~Condition+(1|Partner) + (1|Subject)+(1|dyad), family=binomial, data=xdata[xdata$study=="Kia",], control=contr)

summary(full)

drop1(full, test="Chisq")
drop1(full_study, test="Chisq")
drop1(brauer, test="Chisq")
drop1(kia, test="Chisq")

xdata$Condition=as.factor(xdata$Condition)
#xdata$Condition=relevel(xdata$Condition, ref="Inequity")
#xdata$Condition=relevel(xdata$Condition, ref="Equity")

summary(full)

# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)       3.5215     0.6477   5.437 5.43e-08 ***
#   ConditionEquity   1.1789     0.1959   6.018 1.77e-09 ***
#   ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


exp(1.1789)#3.25 odds larger to exchange in EQ than in IA
confint.merMod(full, method="Wald")

#model stability check

full=glmer(cbind(Exchange, No_exchange)~Condition+(1|Partner)+(1|Subject)+(1|dyad), family=binomial, data=xdata, control=contr)
res=glm(cbind(Exchange, No_exchange)~Condition, data=xdata, family=binomial)
summary(res)
drop1(res, test="Chisq")

xdata$dyad=as.factor(xdata$dyad)
subs=levels(xdata$dyad)

all.coeffs=matrix(NA, nrow=length(subs), ncol=length(coefficients(res)))
colnames(all.coeffs)=names(coefficients(res))
for(i in 1:length(subs)){
  ires=glm(cbind(Exchange, No_exchange)~Condition, data=subset(xdata, dyad!=subs[i]), family=binomial)
  ires=coefficients(ires)
  all.coeffs[i, names(ires)]=ires
}
round(cbind(coefficients(res), t(apply(all.coeffs, 2, range, na.rm=T))), 3)
m.stab=cbind(coefficients(res), t(apply(all.coeffs, 2, range, na.rm=T)))

#Plotting
#Modeling refusals instead of successful exchanges
full=glmer(cbind(No_exchange,Exchange)~Condition+(1|Partner)+(1|Subject)+(1|dyad), family=binomial, data=xdata, control=contr)
drop1(full, test = "Chisq")
summary(full)

library(tidyverse)
library(ggeffects)
library(ggthemes)

df=ggpredict(full, terms="Condition")
df=as.data.frame(df)
str(df)
#levels(df$x)=c("equal", "unequal")
#levels(df$x)=c("equity", "inequity")
colnames(df)[1]=c("Condition")

# Adjusted code with manual color scales
ggplot(df, aes(Condition, predicted, colour = Condition)) +
  geom_boxplot() +
  # geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = .05) +
  geom_point() +
  geom_count(show.legend = FALSE) +
  geom_errorbar(aes(ymin = conf.low, ymax = conf.high, width = 0.2)) +
  scale_y_continuous(breaks = seq(0, 0.1, 0.02), limits = c(0, 0.1)) +
  ylab("Predicted refusal rate") +
  xlab("Condition") +
  scale_color_manual(values = c("blue", "red")) +  # Custom colors for Condition
  scale_fill_manual(values = c("blue", "red")) +   # Matching fill color for consistency
  theme_pander(base_size = 18, base_family = "Times") +
  theme(
    axis.title.y.left = element_text(margin = margin(0, 10, 20, 15)),
    axis.title.x = element_text(margin = margin(t = 10, r = 10, b = 20, l = 15))
  )


###Model 2: Testing the effect of social closeness of IA

ydata <- read.table("Radovanovic et al.IA_bonobos_Study1_model2.txt", header=T, sep="\t")
str(ydata)

full=glmer(No_exchange~z.Trial+z.Session+Sex+Condition*(z.proximity+z.grooming+Order)+(1+z.Session+z.Trial||Subject)+(1+z.Session+z.Trial||Partner)+(1+z.Session+z.Trial||dyad),family=binomial, data=ydata, control=contr)
null=glmer(No_exchange~z.Trial+z.Session+Sex+Order+(1+z.Session+z.Trial||Subject)+(1+z.Session+z.Trial||Partner)+(1+z.Session+z.Trial||dyad),family=binomial, data=ydata, control=contr)

anova(full, null, test="Chisq")

# npar    AIC    BIC  logLik deviance  Chisq Df Pr(>Chisq)  
# null   14 287.42 356.50 -129.71   259.42                       
# full   20 288.64 387.33 -124.32   248.64 10.779  6    0.09544 .

drop1(full, test="Chisq")

# npar    AIC    LRT Pr(Chi)  
# <none>                     288.64                 
# z.Trial                  1 289.08 2.4374 0.11848  
# z.Session                1 287.10 0.4587 0.49824  
# Sex                      1 286.92 0.2744 0.60041  
# Condition:z.proximity    1 287.79 1.1445 0.28471  
# Condition:z.grooming     1 291.13 4.4813 0.03427 *
# Condition:Order      1 288.77 2.1266 0.14476

summary(full)
str(ydata)

#model stability

library(lme4)
library(ggplot2)

# Fit the model to the full dataset
full <- glmer(
  No_exchange ~ z.Trial + z.Session + Sex + Condition * (z.proximity + z.grooming + Order) + 
    (1 + z.Session + z.Trial || Subject) + 
    (1 + z.Session + z.Trial || Partner) + 
    (1 + z.Session + z.Trial || dyad), 
  family = binomial, 
  data = ydata, 
  control = contr
)

summary(full)

exp(-1.28666)
#[1] 0.2761917

# Store original estimates
original_estimates <- fixef(full)

# Define a vector to store dyads
dyads <- unique(ydata$dyad)

# Initialize a matrix to store estimates for each dyad exclusion
all_estimates <- matrix(NA, nrow = length(dyads), ncol = length(original_estimates))
colnames(all_estimates) <- names(original_estimates)

# Loop over dyads, excluding one dyad at a time
for (i in 1:length(dyads)) {
  cat("Processing dyad:", dyads[i], "\n")  # For progress monitoring
  model <- glmer(
    No_exchange ~ z.Trial + z.Session + Sex + Condition * (z.proximity + z.grooming + Order) + 
      (1 + z.Session + z.Trial || Subject) + 
      (1 + z.Session + z.Trial || Partner) + 
      (1 + z.Session + z.Trial || dyad), 
    family = binomial, 
    data = subset(ydata, dyad != dyads[i]), 
    control = contr
  )
  all_estimates[i, ] <- fixef(model)
}

# Compute the range (min and max) for each estimate
estimate_ranges <- apply(all_estimates, 2, function(x) range(x, na.rm = TRUE))

# Add original estimates to the ranges and plot
ranges_df <- data.frame(
  Estimate = names(original_estimates),
  Min = estimate_ranges[1, ],
  Max = estimate_ranges[2, ],
  Original = original_estimates
)

# Plot ranges with the original estimate
ggplot(ranges_df, aes(x = Estimate)) +
  geom_linerange(aes(ymin = Min, ymax = Max), color = "blue", size = 1) +
  geom_point(aes(y = Original), color = "red", size = 3) +
  coord_flip() +
  theme_minimal() +
  labs(
    title = "Fixed Effect Estimates: Ranges and Original Values",
    x = "Fixed Effects",
    y = "Estimate"
  )

ggsave("Figure S2.pdf", width = 6, height = 7)

#Study 2. Replication of the study by Engelmann et al. (2017).

###Model 1. Testing effect of partner present and machine vs human distributor

setwd("~/Documents/Projects 2024-/Inequity PRSB revision 2024/Datasets")
xdata <- read.table("Radovanovic et al.IA_bonobos_Study2.txt", header=T, sep="\t")

str(xdata)

#omit trials in which the bonobo did not take out the tool to begin with
table(xdata$result_refinitiate)
xdata=subset(xdata, xdata$result_refinitiate=="no")

full=glmer(result_refexchange~z.trial+z.session+sex+counterbalance_partner_presence_first+condition_machine*condition_partner+(1+condition_partner+z.session+z.trial||subject)+(1+condition_partner+z.session+z.trial||partner)+(1+z.session+z.trial||dyad),family=binomial, data=xdata, control=contr)
null=glmer(result_refexchange~z.trial+z.session+sex+counterbalance_partner_presence_first+(1+condition_partner+z.session+z.trial||subject)+(1+condition_partner+z.session+z.trial||partner)+(1+z.session+z.trial||dyad),family=binomial, data=xdata, control=contr)

anova(full, null, test="Chisq")

summary(full)

drop1(full, test="Chisq")

#plotting model predictions
library(ggplot2)
library(ggthemes)
library(tidyverse)
library(ggeffects)

df=ggpredict(full, terms=c("condition_machine", "condition_partner"))
df=as.data.frame(df)
str(df)
#levels(df$x)=c("human", "machine")
colnames(df)[1]=c("Condition")

ggplot(df, aes(Condition, predicted, colour= Condition))+
  geom_boxplot()+
  #geom_ribbon(aes(ymin = conf.low, ymax = conf.high), alpha = .05)+
  geom_point()+
  geom_count(show.legend = F)+
  geom_errorbar(aes(ymin = conf.low, ymax = conf.high, width = 0.2))+
  #scale_y_continuous(breaks = seq(0, 0.1, 0.02), limits=c(0,0.1))+
  #theme(axis.text.x=element_text(angle=0,hjust=1))+
  ylab("Predicted refusal rate")+
  xlab("Condition")+
  scale_colour_pander() +
  scale_fill_pander() +
  theme_pander(base_size = 18, base_family = "Times")+
  theme(axis.title.y.left = element_text(margin = margin(0, 10, 20, 15)), axis.title.x = element_text(margin = margin(t=10, r=10, b=20, l=15)))+
  facet_grid(~group)

ggsave("Figure main text Study 2.pdf", width=7, height=7)

#Confidence intervals

confint.merMod(object=full, devtol=1, method=c("Wald"))
#confint.merMod(object=full, method=c("boot"))

#install.packages("emmeans")
library(emmeans)
str(xdata)
emmeans(full, pairwise ~ condition_machine*condition_partner, adjust="tukey")

# $emmeans
# condition_machine condition_partner emmean    SE  df asymp.LCL asymp.UCL
# human             partner_absent     -3.19 0.679 Inf     -4.52    -1.864
# machine           partner_absent     -3.84 0.743 Inf     -5.30    -2.383
# human             partner_present    -5.06 1.215 Inf     -7.44    -2.678
# machine           partner_present    -0.87 0.300 Inf     -1.46    -0.282
# 
# Results are averaged over the levels of: sex, counterbalance_partner_presence_first 
# Results are given on the logit (not the response) scale. 
# Confidence level used: 0.95 
# 
# $contrasts
# contrast                                         estimate    SE  df z.ratio p.value
# human partner_absent - machine partner_absent       0.645 1.134 Inf   0.568  0.9415
# human partner_absent - human partner_present        1.865 1.334 Inf   1.398  0.5005
# human partner_absent - machine partner_present     -2.324 0.758 Inf  -3.066  0.0116
# machine partner_absent - human partner_present      1.220 1.350 Inf   0.904  0.8028
# machine partner_absent - machine partner_present   -2.968 0.830 Inf  -3.578  0.0020
# human partner_present - machine partner_present    -4.188 1.225 Inf  -3.418  0.0035
# 
# Results are averaged over the levels of: sex, counterbalance_partner_presence_first 
# Results are given on the log odds ratio (not the response) scale. 
# P value adjustment: tukey method for comparing a family of 4 estimates 

summary(full)

#model stability

res=glm(result_refexchange~z.trial+z.session+sex+counterbalance_partner_presence_first+condition_machine*condition_partner,family=binomial, data=xdata)
summary(res)
drop1(res, test="Chisq")
str(xdata)

xdata$dyad=as.factor(xdata$dyad)
subs=levels(xdata$dyad)

all.coeffs=matrix(NA, nrow=length(subs), ncol=length(coefficients(res)))
colnames(all.coeffs)=names(coefficients(res))
for(i in 1:length(subs)){
  ires=glm(result_refexchange~z.trial+z.session+sex+counterbalance_partner_presence_first+condition_machine*condition_partner, data=subset(xdata, dyad!=subs[i]), family=binomial)
  ires=coefficients(ires)
  all.coeffs[i, names(ires)]=ires
}
round(cbind(coefficients(res), t(apply(all.coeffs, 2, range, na.rm=T))), 3)
m.stab=round(cbind(coefficients(res), t(apply(all.coeffs, 2, range, na.rm=T))), 3)

#plot model stability

xx=as.data.frame(m.stab)
str(xx)
#xx=read.table("Glmm_modelstab.txt", header=T, sep="\t")
xx[1:13,]
xx=xx[1:nrow(m.stab),]
colnames(xx)=c("orig", "min", "max")
row.names(xx)

library(ggplot2)
library(plyr)
library(scales)

segment_data = data.frame(
  x = xx$min,
  xend = xx$max, 
  y = unname(row.names(xx)),
  yend = unname(row.names(xx)))

ggplot(xx, aes(x=orig, y= row.names(xx)))+
  geom_point()+
  #geom_point(position = position_jitter(w = 0.3, h = 0), colour="darkgrey", alpha=1/2)+
  #geom_boxplot()+
  theme_bw()+
  theme(text=element_text(size=12), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.title=element_text(size=10))+
  geom_segment(data=segment_data, aes(x = x, y = y, xend = xend, yend = yend, col="red"), size=1, show.legend = F)+
  geom_vline(xintercept=0, linetype="dashed", color = "blue", size=0.3)+
  #scale_y_continuous(breaks = seq(-5, 15, by = 5), limits=c(-5,15))+
  scale_x_continuous(breaks = seq(-25, 25, by = 5), limits=c(-25,25))+
  ylab("")+
  xlab("Estimate range")

#ggsave("Figure S4.pdf", width = 10, height = 6)

###Model 2. Check for effect of social closeness in cases where partner was present

str(xdata)
xdata=subset(xdata, xdata$condition_partner=="partner_present")
xdata$Proximity=as.numeric(xdata$Proximity)
xdata$Grooming =as.numeric(xdata$Grooming)
xdata$z.Proximity=as.vector(scale(xdata$Proximity))
xdata$z.Grooming =as.vector(scale(xdata$Grooming))

str(xdata)

full=glmer(result_refexchange~z.trial+z.session+sex+counterbalance_partner_presence_first+condition_machine+z.Proximity+ z.Grooming+(1+session+trial||subject)+(1+z.session+z.trial||partner)+(1+z.session+z.trial||dyad),family=binomial, data=xdata, control=contr)
null=glmer(result_refexchange~z.trial+z.session+sex+counterbalance_partner_presence_first+condition_machine+(1+z.session+z.trial||subject)+(1+z.session+z.trial||partner)+(1+session+trial||dyad),family=binomial, data=xdata, control=contr)

anova(full, null, test="Chisq")

# npar    AIC    BIC  logLik deviance  Chisq Df Pr(>Chisq)
# null   15 146.96 199.60 -58.482   116.96                     
# full   17 150.00 209.66 -58.001   116.00 0.9619  2     0.6182

summary(full)

drop1(full, test="Chisq")

#                                      npar    AIC     LRT  Pr(Chi)   
# <none>                                     150.00                    
# z.trial                                  1 150.51  2.5088 0.113211   
# z.session                                1 148.06  0.0559 0.813138   
# sex                                      1 149.35  1.3467 0.245861   
# counterbalance_partner_presence_first    1 152.41  4.4051 0.035832 * 
# condition_machine                        1 158.39 10.3922 0.001265 **
# z.Proximity                              1 148.51  0.5104 0.474974   
# z.Grooming                               1 148.30  0.3020 0.582626   

#Model 3. Test for opt-out usage across conditions

xdata <- read.table("Radovanovic et al.IA_bonobos_Study2.txt", header=T, sep="\t")
str(xdata)

#omit trials in which the bonobo did not take out the tool to begin with
table(xdata$result_refinitiate)
xdata=subset(xdata, xdata$result_refinitiate=="no")
table(xdata$result_optout)

full_optout=glmer(result_optout~z.trial+z.session+sex+counterbalance_partner_presence_first+condition_machine*condition_partner+(1+condition_partner+z.session+z.trial||subject)+(1+condition_partner+z.session+z.trial||partner)+(1+z.session+z.trial||dyad),family=binomial, data=xdata, control=contr)
null_optout=glmer(result_optout~z.trial+z.session+sex+counterbalance_partner_presence_first+(1+condition_partner+z.session+z.trial||subject)+(1+condition_partner+z.session+z.trial||partner)+(1+z.session+z.trial||dyad),family=binomial, data=xdata, control=contr)

anova(full_optout, null_optout, test="Chisq")
